Installation
============


We recommend Python v3.6 or higher.

PyPI, Virtualenv, or Anaconda
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

You can use ``pip`` (or ``pip3``):

.. code-block:: bash
		
    pip install schema_learn



Docker
~~~~~~

Schema has been designed to be compatible with the popular and excellent single-cell Python package, Scanpy_.
We recommend installing the Docker image recommended_ by Scanpy maintainers and then using ``pip``, as described above, to install Schema in it.


.. _Scanpy: http://scanpy.readthedocs.io

.. _recommended: https://scanpy.readthedocs.io/en/1.4.4.post1/installation.html#docker
